# coding: utf-8

"""
    VNS3 Controller API

    Cohesive networks VNS3 API providing complete control of your network's addresses, routes, rules and edge  # noqa: E501

    The version of the OpenAPI document: 4.8
    Contact: solutions@cohesive.net
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import pytest

import cohesivenet
from cohesivenet.api.vns3.licensing_api import LicensingApi  # noqa: E501
from cohesivenet.rest import ApiException


class TestLicensingApi(object):
    """LicensingApi unit test stubs"""

    @pytest.mark.licensed
    def test_get_license(self):
        """Test case for get_license

        """
        pass

    @pytest.mark.licensed
    def test_put_license_upgrade(self):
        """Test case for put_license_upgrade

        """
        pass

    def test_put_set_license_parameters(self):
        """Test case for put_set_license_parameters

        """
        pass

    def test_upload_license(self):
        """Test case for upload_license

        """
        pass
